@@ -515,10 +515,6 @@ class LiveCDCopyBackend(backend.AnacondaBackend):
 
         cmdline_str = ' '.join(cmdline_args)
 
-        # if root_device or swap encrypted, replace splash=silent
-        if root_crypted or swap_crypted or any_crypted:
-            cmdline_str = cmdline_str.replace('splash=silent', 'splash=verbose')
-
         log.info("_setup_grub2, grub_target: %s | "
             "boot_device: %s | cmdline_str: %s" % (grub_target,
             boot_device, cmdline_str,))
@@ -572,12 +568,18 @@ password root """+str(self.anaconda.bootloader.pure)+"""
         if os.path.isfile(dev_map):
             os.remove(dev_map)
 
+        # disable efi by forcing i386-pc if noefi is set
+        efi_args = []
+        if flags.cmdline.has_key("noefi"):
+            # we assume that we only support x86_64 and i686
+            efi_args.append("--target=i386-pc")
+
         # this must be done before, otherwise gfx mode is not enabled
         grub2_install = self._root + "/usr/sbin/grub2-install"
         if os.path.lexists(grub2_install):
             iutil.execWithRedirect('/usr/sbin/grub2-install',
                                    ["/dev/" + grub_target,
-                                    "--recheck", "--force"],
+                                    "--recheck", "--force"] + efi_args,
                                    stdout = PROGRAM_LOG_FILE,
                                    stderr = PROGRAM_LOG_FILE,
                                    root = self._root
@@ -585,7 +587,7 @@ password root """+str(self.anaconda.bootloader.pure)+"""
         else:
             iutil.execWithRedirect('/sbin/grub2-install',
                                    ["/dev/" + grub_target,
-                                    "--recheck", "--force"],
+                                    "--recheck", "--force"] + efi_args,
                                    stdout = PROGRAM_LOG_FILE,
                                    stderr = PROGRAM_LOG_FILE,
                                    root = self._root
